@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: scriptLibInfo.php 3424 2010-07-23 07:40:00Z fishbone $
+ * @version    SVN: $Id: scriptLibInfo.php 3441 2010-07-30 05:49:31Z fishbone $
  * @link       http://www.magic3.org
  */
 class ScriptLibInfo
@@ -42,8 +42,10 @@ class ScriptLibInfo
 	const LIB_JQUERY_FACEBOX		= 'jquery.facebox';
 	const LIB_JQUERY_CURVYCORNERS	= 'jquery.curvycorners';
 	const LIB_JQUERY_PRETTYPHOTO	= 'jquery.prettyphoto';
+	const LIB_JQUERY_QTIP			= 'jquery.qtip';
 	// jQueryプラグインバージョン
 	const JQUERY_PRETTYPHOTO_VER	= '2.5.6';
+	const JQUERY_QTIP_VER			= '1.0';
 	
 	// jQuery UI
 	const LIB_JQUERY_UI_WIDGETS_ACCORDION		= 'jquery-ui.accordion';		// Widgets Accordion
@@ -82,12 +84,14 @@ class ScriptLibInfo
 	const JQUERY_CURVYCORNERS_FILENAME	= 'jquery/jquery.curvycorners.packed.js';
 	const JQUERY_PRETTYPHOTO_FILENAME	= 'jquery/jquery.prettyPhoto.js';
 	const JQUERY_PRETTYPHOTO_CSS		= 'jquery/prettyPhoto/css/prettyPhoto.css';
+	const JQUERY_QTIP_FILENAME			= 'jquery/jquery.qtip-1.0.min.js';
 	
 	// ライブラリの公式サイトのURL
 	const JQUERY_CLUETIP_URL			= 'http://plugins.learningjquery.com/cluetip/';
 	const JQUERY_FACEBOX_URL			= 'http://defunkt.github.com/facebox/';
 	const JQUERY_CURVYCORNERS_URL		= 'http://code.google.com/p/jquerycurvycorners/';
 	const JQUERY_PRETTYPHOTO_URL		= 'http://www.no-margin-for-errors.com/projects/prettyphoto-jquery-lightbox-clone/';
+	const JQUERY_QTIP_URL				= 'http://craigsworks.com/projects/qtip/';
 	
 	// ファイル名
 	const JQUERY_FILENAME			= 'jquery-1.2.6.pack.js';					// JQuery
@@ -202,7 +206,10 @@ class ScriptLibInfo
 					self::LIB_JQUERY_PRETTYPHOTO	=>	array(	'script' 	=> array(self::JQUERY_PRETTYPHOTO_FILENAME),	// jquery.prettyPhoto用のファイル
 																'css'		=>	array(self::JQUERY_PRETTYPHOTO_CSS),
 																'url'		=>	self::JQUERY_PRETTYPHOTO_URL,
-																'version'	=>	self::JQUERY_PRETTYPHOTO_VER)
+																'version'	=>	self::JQUERY_PRETTYPHOTO_VER),
+					self::LIB_JQUERY_QTIP			=>	array(	'script' 	=> array(self::JQUERY_QTIP_FILENAME),	// jquery.qtip用のファイル
+																'url'		=>	self::JQUERY_QTIP_URL,
+																'version'	=>	self::JQUERY_QTIP_VER)
 																);
 					
 		// 使用するjQueryバージョンに合わせてファイルを追加
