@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 3101 2010-05-07 06:02:10Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 3186 2010-06-05 12:16:10Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -82,8 +82,11 @@ class BaseFrameContainer extends Core
 				$clientId = $this->gAccess->createClientId();
 			} else {
 				$this->gAccess->setClientId($clientId);	// クライアントIDを設定
+				
+				// クッキーの使用可否を設定
+				$this->gEnv->setCanUseCookie(true);
 			}
-			$request->setCookieValue(M3_COOKIE_CLIENT_ID, $clientId);
+			$request->setCookieValue(M3_COOKIE_CLIENT_ID, $clientId, M3_COOKIE_EXPIRE_CLIENT_ID);
 			
 			// 引数での言語設定取得、言語変更可能な場合は変更
 			// 言語の優先順は、URLの言語設定、クッキーの言語設定の順
