@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 1.10.x SVN: $Id: global.php 3446 2010-08-01 08:51:55Z fishbone $
+ * @version    Release 1.15.x SVN: $Id: global.php 3472 2010-08-13 04:09:14Z fishbone $
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -44,8 +44,8 @@ define('M3_ENCODING',	'UTF-8');	// 内部エンコーディング
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
 //define('M3_SYSTEM_VERSION',			'1.12.2');		// システムのバージョン
-define('M3_SYSTEM_VERSION',			'1.15.2');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2010/7/26');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'1.15.4');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2010/8/9');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -181,8 +181,10 @@ define('M3_REQUEST_PARAM_CONTENT_ID',      			'contentid');		// コンテンツI
 define('M3_REQUEST_PARAM_CONTENT_ID_SHORT',      	'cid');				// コンテンツID(略式)
 define('M3_REQUEST_PARAM_PRODUCT_ID',      			'productid');		// 製品ID
 define('M3_REQUEST_PARAM_PRODUCT_ID_SHORT',      	'pid');				// 製品ID(略式)
-define('M3_REQUEST_PARAM_BLOG_ID',      			'entryid');			// ブログ記事ID
-define('M3_REQUEST_PARAM_BLOG_ID_SHORT',      		'eid');				// ブログ記事ID(略式)
+define('M3_REQUEST_PARAM_BLOG_ID',      			'blogid');			// ブログID
+define('M3_REQUEST_PARAM_BLOG_ID_SHORT',      		'bid');				// ブログID(略式)
+define('M3_REQUEST_PARAM_BLOG_ENTRY_ID',      		'entryid');			// ブログ記事ID
+define('M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT',      'eid');				// ブログ記事ID(略式)
 define('M3_REQUEST_PARAM_BBS_ID',      				'bbsid');			// 掲示板投稿記事ID
 define('M3_REQUEST_PARAM_BBS_ID_SHORT',      		'bid');				// 掲示板投稿記事ID(略式)
 define('M3_REQUEST_PARAM_BBS_THREAD_ID',      		'threadid');		// 掲示板投稿スレッドID
