@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainInitsystemWidgetContainer.php 2235 2009-08-19 02:00:26Z fishbone $
+ * @version    SVN: $Id: admin_mainInitsystemWidgetContainer.php 2363 2009-09-26 14:45:44Z fishbone $
  * @link       http://www.magic3.org
  */
 //require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -65,7 +65,7 @@ class admin_mainInitsystemWidgetContainer extends admin_mainBaseWidgetContainer
 			$this->gSystem->enableInitSystem();
 			
 			// インストーラを回復
-			$this->gFile->recoverInstaller();
+			$this->gInstance->getFileManager()->recoverInstaller();
 			
 			$this->setMsg(self::MSG_GUIDANCE, 'システム初期化完了しました<br>一旦ログアウトしてください');
 			
@@ -73,8 +73,10 @@ class admin_mainInitsystemWidgetContainer extends admin_mainBaseWidgetContainer
 			$request->unsetSessionValue(M3_SESSION_CURRENT_TEMPLATE);
 		} else if ($act == 'initother'){		// 追加テーブル再作成のとき
 			// DB初期化実行
-			$ret = $this->gDb->execInitScript('base', $errors);// 標準テーブル
-			if ($ret) $ret = $this->gDb->execInitScript('ec', $errors);// ECテーブル
+			//$ret = $this->gDb->execInitScript('base', $errors);// 標準テーブル
+			$ret = $this->gInstance->getDbManager()->execInitScript('base', $errors);// 標準テーブル
+			//if ($ret) $ret = $this->gDb->execInitScript('ec', $errors);// ECテーブル
+			if ($ret) $ret = $this->gInstance->getDbManager()->execInitScript('ec', $errors);// ECテーブル
 			if ($ret){
 				$this->setMsg(self::MSG_GUIDANCE, 'テーブル再作成完了しました');
 			} else {
@@ -92,7 +94,8 @@ class admin_mainInitsystemWidgetContainer extends admin_mainBaseWidgetContainer
 			$scriptPath = $this->gEnv->getSqlPath() . '/' . self::SAMPLE_DIR . '/' . $filename;
 			
 			// スクリプト実行
-			if ($this->gDb->execScriptWithConvert($scriptPath, $errors)){// 正常終了の場合
+			//if ($this->gDb->execScriptWithConvert($scriptPath, $errors)){// 正常終了の場合
+			if ($this->gInstance->getDbManager()->execScriptWithConvert($scriptPath, $errors)){// 正常終了の場合
 				$this->setMsg(self::MSG_GUIDANCE, 'スクリプト実行完了しました');
 			} else {
 				$this->setMsg(self::MSG_APP_ERR, "スクリプト実行に失敗しました");
@@ -168,7 +171,8 @@ class admin_mainInitsystemWidgetContainer extends admin_mainBaseWidgetContainer
 		}
 		
 		// ディスク使用量取得
-		$diskByte = $this->gDb->getTableDataSize('_access_log');
+		//$diskByte = $this->gDb->getTableDataSize('_access_log');
+		$diskByte = $this->gInstance->getDbManager()->getTableDataSize('_access_log');
 		$this->tmpl->addVar("_widget", "size_access_log", convFromBytes($diskByte));
 	}
 }
