@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 3384 2010-07-17 04:56:39Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 3454 2010-08-06 02:57:16Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_blog_mainBaseWidgetContainer.php');
@@ -714,8 +714,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		if ($ret){
 			$entryId = $row['be_id'];		// 記事ID
 			$urlParam = array();
-			$urlParam[] = M3_REQUEST_PARAM_BLOG_ID . '=' . $entryId;		// 記事ID
-			$urlParam[] = M3_REQUEST_PARAM_BLOG_ID_SHORT . '=' . $entryId;		// 記事ID略式
+			$urlParam[] = M3_REQUEST_PARAM_BLOG_ENTRY_ID . '=' . $entryId;		// 記事ID
+			$urlParam[] = M3_REQUEST_PARAM_BLOG_ENTRY_ID_SHORT . '=' . $entryId;		// 記事ID略式
 			$this->clearCache($urlParam);
 		}
 	}
