@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainWidgetContainer.php 2231 2009-08-17 03:13:16Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainWidgetContainer.php 2932 2010-03-17 14:19:25Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_blog_mainBaseWidgetContainer.php');
@@ -74,7 +74,7 @@ class admin_blog_mainWidgetContainer extends admin_blog_mainBaseWidgetContainer
 			$this->gLaunch->goSubWidget($task, true);		// 管理者機能で呼び出し
 			return false;
 		} else {
-			$this->SetMsg(0, "画面が見つかりません");
+			$this->SetMsg(self::MSG_APP_ERR, "画面が見つかりません");
 			return true;
 		}
 	}
