@@ -9,9 +9,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 2481 2009-10-29 03:56:56Z fishbone $
+ * @version    SVN: $Id: index.php 3137 2010-05-18 05:57:59Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -43,7 +43,7 @@ $HELP['content_update_dt']['body'] = 'コンテンツを更新した日時です
 $HELP['content_view_count']['title'] = '閲覧数';
 $HELP['content_view_count']['body'] = 'コンテンツがユーザに閲覧された回数です。管理者の閲覧はカウントされません。';
 $HELP['content_act']['title'] = '操作';
-$HELP['content_act']['body'] = '各種操作を行います。<br />●メニューに追加<br />「メインメニュー」ウィジェットにコンテンツを表示するメニュー項目を追加します。';
+$HELP['content_act']['body'] = '各種操作を行います。<br />●メニューに追加<br />メニュー定義にコンテンツを表示するメニュー項目を追加します。';
 $HELP['content_html']['title'] = 'HTML';
 $HELP['content_html']['body'] = 'コンテンツの内容となるHTMLです。';
 $HELP['content_ref_custom']['title'] = '置換文字列を参照';
